createSubbasin.base <-
function(name,
         precipitation,
         inflow,
         Area,
         delayInflow,
         downstream,
         transformMethod,
         lossMethod,
         BFSMethod,
         UH,
         abstractionParams,
         transformParams,
         lossParams,
         BFSParams)
{
   subBasin<-list(name=name,
                  precipitation=precipitation,
                  Area=Area,
                  delayInflow=delayInflow,
                  label=runif(1),
                  downstream=downstream,
                  inflow=inflow,
                  transformMethod=transformMethod,
                  lossMethod=lossMethod,
                  BFSMethod=BFSMethod,
                  UH=UH,
                  abstractionParams=abstractionParams,
                  transformParams=transformParams,
                  lossParams=lossParams,
                  BFSParams=BFSParams)
   return(subBasin) 
}